pub struct BlockchainDatabase { /* private fields */ }Expand description
The blockchain database.
Implementations
Sourceimpl BlockchainDatabase
impl BlockchainDatabase
Sourcepub fn open_with_fjall_database(
config: &Config,
fjall: Database,
) -> Result<Self, BlockchainError>
pub fn open_with_fjall_database( config: &Config, fjall: Database, ) -> Result<Self, BlockchainError>
Open a BlockchainDatabase with an [fjall::Database] for storing data that can’t be stored in tapes.
Sourcepub fn make_consistent(&mut self) -> Result<(), BlockchainError>
pub fn make_consistent(&mut self) -> Result<(), BlockchainError>
Checks if the fjall and tapes database are in sync and rebuilds the fjall database if it is not.
Sourcepub fn rebuild_fjall_database(&mut self) -> Result<(), BlockchainError>
pub fn rebuild_fjall_database(&mut self) -> Result<(), BlockchainError>
Rebuilds the fjall database.